@@ -488,6 +488,91 @@ def special_service(request, output):
     output['finish'] = True
 
 
+class SpecialGatewayApi(tornado.web.RequestHandler):
+
+    async def get(self, *args, **kwargs):
+        output = {
+            'result': {},
+            'finish': False
+        }
+        thread = threading.Thread(
+            target=gateway_data_service,
+            args=(self.request, output)
+        )
+        thread.setDaemon(True)
+        thread.start()
+
+        while not output['finish']:
+            await asyncio.sleep(0.01)
+
+        result = output['result']
+
+        if result['status'] == 'ok':
+            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
+            new_refresh_token = result['value'].get('new_refresh_token')
+            response = result['value']['response']
+            if new_access_token is not None and new_refresh_token is not None:
+                self.set_cookie('access_token', new_access_token)
+                self.set_cookie('refresh_token', new_refresh_token)
+
+            self.set_status(response.status_code)
+            try:
+                json.loads(response.text, encoding='utf-8')
+            except:
+                self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
+            self.set_header("Access-Control-Allow-Origin", "*")  # 允许跨域访问
+            self.write(response.content)
+        else:
+            self.set_status(500)
+            self.write(result['value'])
+
+    async def post(self, *args, **kwargs):
+        output = {
+            'result': {},
+            'finish': False
+        }
+        thread = threading.Thread(
+            target=gateway_data_service,
+            args=(self.request, output)
+        )
+        thread.setDaemon(True)
+        thread.start()
+
+        while not output['finish']:
+            await asyncio.sleep(0.01)
+
+        result = output['result']
+
+        if result['status'] == 'ok':
+            new_access_token = result['value'].get('new_access_token')  # 用 get 而不是 [] 来取值，因为可能不存在
+            new_refresh_token = result['value'].get('new_refresh_token')
+            response = result['value']['response']
+
+            if new_access_token is not None and new_refresh_token is not None:
+                self.set_cookie('access_token', new_access_token)
+                self.set_cookie('refresh_token', new_refresh_token)
+
+            self.set_status(response.status_code)
+            try:
+                json.loads(response.text, encoding='utf-8')
+            except:
+                self._headers = HTTPHeaders(response.headers)  # 注意：需要强制类型转换
+            self.set_header('Access-Control-Allow-Credentials', 'true')
+            self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+            self.write(response.content)
+        else:
+            self.set_status(500)
+            self.write(result['value'])
+
+    async def options(self, *args, **kwargs):
+        # 允许跨域
+        self.set_status(204)
+        self.set_header('Access-Control-Allow-Credentials', 'true')
+        self.set_header('Access-Control-Allow-Origin', self.request.headers.get('Origin'))
+        self.set_header("Access-Control-Allow-Headers", "content-type")
+        self.set_header('Access-Control-Allow-Methods', 'GET, POST, OPTIONS')
+
+
 class HealthChecker(tornado.web.RequestHandler):
     def get(self, *args, **kwargs):
         self.write('{"description": "Micro-service Discovery Client", "status": "UP"}')
@@ -547,7 +632,7 @@ def start():
         g.is_gateway = True
         handlers = [
             (r'/management/health', HealthChecker),
-            (r'/special/(.*)', SpecialApi),
+            (r'/special/(.*)', SpecialGatewayApi),
             (r'/api/data', DataApi),
             (r'/(.*)', GatewayApi),
         ]
